CommandError

Enum CommandError 

pub enum CommandError {
    Timeout,
    CellNotPresent,
    ApiError,
    CellError,
    Internal,
    SmallBuffer,
    Other(i32),
}
Why sending a command to a cell failed.

Variants



Timeout

No response received within the timeout



CellNotPresent

The indicated cell is not present in the system (TODO we need some kind of cell registry for this)



ApiError

The cell exists, but either does not have the specified command or the provided arguments are invalid (e.g., arguments were provided to a cell not expecting input or vice versa)



CellError

The receiving cell crashed/errored out while processing the query



Internal

Internal errors within the framework



SmallBuffer

The provided buffer was too small for the response



Other(i32)

Catchall for other error codes (should not be used)

Implementations

Source

impl CommandError

pub fn describe(&self) -> &'static str

A short human-readable description of the error (also its Display output).