SpawnError

Enum SpawnError 

pub enum SpawnError {
    ClassNotFound,
    AlreadyExists,
    DeployFailed,
}
Errors that can occur when spawning a cell.

Variants



ClassNotFound

No cell class with the given hash or name is registered.



AlreadyExists

The caller already has a child with that local name.



DeployFailed

The deploy failed after the child’s name was claimed.